---
title: <span class="badge object-type-scalar"></span> MillisievertPerHour
---
# <span class="badge object-type-scalar"></span> MillisievertPerHour

Radiation: milliSievert/hour (mSv/h)

## Definition

```python
# Radiation: milliSievert/hour (mSv/h)
MillisievertPerHour: typing.Literal["radmsvh"] = "radmsvh"
```
